==> eclipse-2.1.3_1.tgz: org/eclipse/jface/text/ConfigurableLineTracker.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2003 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.jface.text;




/**
 * Standard implementation of a generic <code>ILineTracker</code>.
 * The line tracker can be configured with the set of legal line delimiters.
 * Line delimiters are unconstrainted. The line delimiters are used to
 * compute the tracker's line structure. In the case of overlapping line delimiters,
 * the longest line delimiter is given precedence of the shorter ones.<p>
 * This class is not intended to be subclassed.
 */
public class ConfigurableLineTracker extends AbstractLineTracker {
	
	
	/** The strings which are considered being the line delimiter */
	private String[] fDelimiters;
	/** A predefined delimiter info which is always reused as return value */
	private DelimiterInfo fDelimiterInfo= new DelimiterInfo(); 
	
	
	/**
	 * Creates a standard line tracker for the given line delimiters.
	 *
	 * @param legalLineDelimiters the tracker's legal line delimiters,
	 *		may not be <code>null</code> and must be longer than 0
	 */
	public ConfigurableLineTracker(String[] legalLineDelimiters) {
		Assert.isTrue(legalLineDelimiters != null && legalLineDelimiters.length > 0);
		fDelimiters= legalLineDelimiters;
	}
	
	/*
	 * @see ILineDelimiter@getLegalLineDelimiters()
	 */
	public String[] getLegalLineDelimiters() {
		return fDelimiters;
	}

	/*
	 * @see AbstractLineTracker#nextDelimiterInfo(String, int)
	 */
	protected DelimiterInfo nextDelimiterInfo(String text, int offset) {
		int[] info= TextUtilities.indexOf(fDelimiters, text, offset);
		if (info[0] == -1)
			return null;
			
		fDelimiterInfo.delimiterIndex= info[0];
		fDelimiterInfo.delimiter= fDelimiters[info[1]];
		fDelimiterInfo.delimiterLength= fDelimiterInfo.delimiter.length();
		return fDelimiterInfo;
	}
}

==> eclipse-3.0.1_2.tgz: org/eclipse/jface/text/ConfigurableLineTracker.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials 
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.jface.text;


/**
 * Standard implementation of a generic
 * {@link org.eclipse.jface.text.ILineTracker}.
 * <p>
 * The line tracker can be configured with the set of legal line delimiters.
 * Line delimiters are unconstrained. The line delimiters are used to compute
 * the tracker's line structure. In the case of overlapping line delimiters, the
 * longest line delimiter is given precedence of the shorter ones.
 * <p>
 * This class is not intended to be subclassed.
 */
public class ConfigurableLineTracker extends AbstractLineTracker {
	
	
	/** The strings which are considered being the line delimiter */
	private String[] fDelimiters;
	/** A predefined delimiter information which is always reused as return value */
	private DelimiterInfo fDelimiterInfo= new DelimiterInfo(); 
	
	
	/**
	 * Creates a standard line tracker for the given line delimiters.
	 *
	 * @param legalLineDelimiters the tracker's legal line delimiters,
	 *		may not be <code>null</code> and must be longer than 0
	 */
	public ConfigurableLineTracker(String[] legalLineDelimiters) {
		Assert.isTrue(legalLineDelimiters != null && legalLineDelimiters.length > 0);
		fDelimiters= legalLineDelimiters;
	}
	
	/*
	 * @see org.eclipse.jface.text.ILineTracker#getLegalLineDelimiters()
	 */
	public String[] getLegalLineDelimiters() {
		return fDelimiters;
	}

	/*
	 * @see org.eclipse.jface.text.AbstractLineTracker#nextDelimiterInfo(java.lang.String, int)
	 */
	protected DelimiterInfo nextDelimiterInfo(String text, int offset) {
		int[] info= TextUtilities.indexOf(fDelimiters, text, offset);
		if (info[0] == -1)
			return null;
			
		fDelimiterInfo.delimiterIndex= info[0];
		fDelimiterInfo.delimiter= fDelimiters[info[1]];
		fDelimiterInfo.delimiterLength= fDelimiterInfo.delimiter.length();
		return fDelimiterInfo;
	}
}
